==> apache-eventmesh-1.4.0-incubating-source.tar.gz: apache-eventmesh-1.4.0-incubating-src/eventmesh-trace-plugin/eventmesh-trace-api/src/main/java/org/apache/eventmesh/trace/api/TracePluginFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.eventmesh.trace.api;

import static com.google.common.base.Preconditions.checkNotNull;

import org.apache.eventmesh.spi.EventMeshExtensionFactory;

import lombok.experimental.UtilityClass;

/**
 * to get the trace service
 */
@UtilityClass
public class TracePluginFactory {
    /**
     * to get TraceService
     *
     * @param traceServiceType
     * @return
     */
    public static TraceService getTraceService(String traceServiceType) {
        checkNotNull(traceServiceType, "traceServiceType cannot be null");

        TraceService traceService = EventMeshExtensionFactory.getExtension(TraceService.class, traceServiceType);
        return checkNotNull(traceService, "traceServiceType: " + traceServiceType + " is not supported");
    }
}

==> apache-eventmesh-1.6.0-incubating-source.tar.gz: apache-eventmesh-1.6.0-incubating-src/eventmesh-trace-plugin/eventmesh-trace-api/src/main/java/org/apache/eventmesh/trace/api/TracePluginFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.eventmesh.trace.api;

import static com.google.common.base.Preconditions.checkNotNull;

import org.apache.eventmesh.spi.EventMeshExtensionFactory;

import lombok.experimental.UtilityClass;

/**
 * to get the trace service
 */
@UtilityClass
public class TracePluginFactory {
    /**
     * to get TraceService
     *
     * @param traceServiceType
     * @return
     */
    public static EventMeshTraceService getEventMeshTraceService(String traceServiceType) {
        checkNotNull(traceServiceType, "traceServiceType cannot be null");

        EventMeshTraceService eventMeshTraceService = EventMeshExtensionFactory.getExtension(EventMeshTraceService.class, traceServiceType);
        return checkNotNull(eventMeshTraceService, "traceServiceType: " + traceServiceType + " is not supported");
    }
}
